<?php

namespace Litecms\Student\Http\Controllers;

use App\Http\Controllers\PublicController as BaseController;
use Litecms\Student\Interfaces\StudentRepositoryInterface;

class StudentPublicController extends BaseController
{
    // use StudentWorkflow;

    /**
     * Constructor.
     *
     * @param type \Litecms\Student\Interfaces\StudentRepositoryInterface $student
     *
     * @return type
     */
    public function __construct(StudentRepositoryInterface $student)
    {
        $this->repository = $student;
        parent::__construct();
    }

    /**
     * Show student's list.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function index()
    {
        $students = $this->repository
        ->pushCriteria(app('Litepie\Repository\Criteria\RequestCriteria'))
        ->scopeQuery(function($query){
            return $query->orderBy('id','DESC');
        })->paginate();


        return $this->response->title(trans('$student::$student.names'))
            ->view('$student::public.student.index')
            ->data(compact('$students'))
            ->output();
    }

    /**
     * Show student's list based on a type.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function list($type = null)
    {
        $students = $this->repository
        ->pushCriteria(app('Litepie\Repository\Criteria\RequestCriteria'))
        ->scopeQuery(function($query){
            return $query->orderBy('id','DESC');
        })->paginate();


        return $this->response->title(trans('$student::$student.names'))
            ->view('$student::public.student.index')
            ->data(compact('$students'))
            ->output();
    }

    /**
     * Show student.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show($slug)
    {
        $student = $this->repository->scopeQuery(function($query) use ($slug) {
            return $query->orderBy('id','DESC')
                         ->where('slug', $slug);
        })->first(['*']);

        return $this->response->title($$student->name . trans('$student::$student.name'))
            ->view('$student::public.student.show')
            ->data(compact('$student'))
            ->output();
    }

}
